# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# NOTE! THIS FILE IS AUTOMATICALLY GENERATED AND WILL BE
# OVERWRITTEN WHEN PREPARING PACKAGES.
#
# IF YOU WANT TO MODIFY IT, YOU SHOULD MODIFY THE TEMPLATE
# `get_provider_info_TEMPLATE.py.jinja2` IN the `provider_packages` DIRECTORY


def get_provider_info():
    return {
        "package-name": "apache-airflow-providers-apache-impala",
        "name": "Apache Impala",
        "description": "`Apache Impala <https://impala.apache.org/>`__.\n",
        "suspended": False,
        "versions": ["1.2.0", "1.1.3", "1.1.2", "1.1.1", "1.1.0", "1.0.0"],
        "dependencies": ["impyla>=0.18.0,<1.0", "apache-airflow>=2.5.0"],
        "integrations": [
            {
                "integration-name": "Apache Impala",
                "external-doc-url": "https://impala.apache.org",
                "tags": ["apache"],
            }
        ],
        "hooks": [
            {
                "integration-name": "Apache Impala",
                "python-modules": ["airflow.providers.apache.impala.hooks.impala"],
            }
        ],
        "connection-types": [
            {
                "hook-class-name": "airflow.providers.apache.impala.hooks.impala.ImpalaHook",
                "connection-type": "impala",
            }
        ],
        "additional-extras": [{"name": "kerberos", "dependencies": ["kerberos>=1.3.0"]}],
    }
